server_client_20141211_231026

### config1 : test_client_timeout

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 61.2968969345 sec | 64.3635041714 sec

Error message: Did not properly handle client timeout

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.87 | 0.1 | 0.068 | 0.1 | 0.12 | 0.12 | 0.13 | 0.15 | 0.033
qps | 621.00 | 500.50 | 380.00 | 500.50 | 560.75 | 596.90 | 608.95 | 618.59 | 120.50

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1260.64 | 1260.64 | 1260.64 | 1260.64 | 1260.64 | 1260.64 | 1260.64 | 1260.64 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.105
server1-perf | latency | mean lt 0.33 | 0.101766233766
server1-perf | qps | mean lt 7.0 | 500.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1260.644
client1-perf | latency | mean lt 35.0 | 1260.644
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None